@@ -6,7 +6,11 @@ receptiviti_status <- function(url = Sys.getenv("RECEPTIVITI_URL"), key = Sys.ge
   if (key == "") stop("specify your key, or set it to the RECEPTIVITI_KEY environment variable", call. = FALSE)
   if (secret == "") stop("specify your secret, or set it to the RECEPTIVITI_SECRET environment variable", call. = FALSE)
   handler <- new_handle(httpauth = 1, userpwd = paste0(key, ":", secret))
-  url <- paste0(sub("(?:/v\\d+)?/+$", "", url), "/v1/ping")
+  url <- paste0(
+    if (!grepl("http", tolower(url), fixed = TRUE)) "https://",
+    sub("/[Vv]\\d(?:/.*)?$|/+$", "", url), "/v1/ping"
+  )
+  if (!grepl("^https?://[^.]+[.:][^.]", url, TRUE)) stop("url does not appear to be valid: ", url)
   ping <- curl_fetch_memory(url, handler)
   ping$content <- list(message = rawToChar(ping$content))
   if (substr(ping$content, 1, 1) == "{") ping$content <- fromJSON(ping$content$message)
